@@ -90,7 +90,8 @@ class Attribute:
   @classmethod
   def from_param(cls, param, ctx):
     const = pytd.Constant(param.name, param.type, param.optional)
-    return cls.from_pytd_constant(const, ctx, kw_only=param.kwonly)
+    return cls.from_pytd_constant(
+        const, ctx, kw_only=param.kind == pytd.ParameterKind.KWONLY)
 
   def to_pytd_constant(self):
     # TODO(mdemello): This is a bit fragile, but we only call this when
@@ -448,7 +449,7 @@ class Class(metaclass=mixin.MixinMeta):  # pylint: disable=undefined-variable
       if self.cls.full_name != "builtins.type":
         # This class has a custom metaclass; check if it defines __getitem__.
         _, att = self.ctx.attribute_handler.get_attribute(
-            node, self, name, self.to_binding(node))
+            node, self.cls, name, self.to_binding(node))
         if att:
           return att
       # Treat this class as a parameterized container in an annotation. We do
