@@ -342,6 +342,10 @@ def add_debug_options(o):
       "--debug-logs", action="store_true",
       dest="debug_logs", default=None,
       help=("Add debugging information to the logs"))
+  o.add_argument(
+      "--exec-log", type=str, action="store",
+      dest="exec_log", default=None,
+      help=("Write pytype execution details to the specified file."))
   o.add_argument(
       "--verify-pickle", action="store_true", default=False,
       dest="verify_pickle",
@@ -574,6 +578,9 @@ class Postprocessor:
       self.error("Not allowed with --no-report-errors", "output-errors-csv")
     self.output_options.output_errors_csv = output_errors_csv
 
+  def _store_exec_log(self, exec_log):
+    self.output_options.exec_log = exec_log
+
   def _store_color(self, color):
     if color not in ("always", "auto", "never"):
       raise ValueError(f"--color flag allows only 'always', 'auto' or 'never', "
