@@ -19,6 +19,7 @@ from pytype.abstract import function
 from pytype.abstract import mixin
 from pytype.pyc import opcodes
 from pytype.pytd import mro
+from pytype.pytd import pytd
 from pytype.pytd import slots
 from pytype.typegraph import cfg
 
@@ -417,6 +418,28 @@ def _expand_generic_protocols(node, bases, ctx):
   return expanded_bases
 
 
+def _check_final_members(cls, class_dict, ctx):
+  """Check if the new class overrides a final attribute or method."""
+  methods = class_dict.keys()
+  for base in cls.mro[1:]:
+    if isinstance(base, abstract.PyTDClass):
+      # TODO(mdemello): Unify this with IntepreterClass
+      for m in methods:
+        member = base.final_members.get(m)
+        if isinstance(member, pytd.Function):
+          ctx.errorlog.overriding_final_method(ctx.vm.frames, cls, base, m)
+        elif member:
+          ctx.errorlog.overriding_final_attribute(ctx.vm.frames, cls, base, m)
+    elif isinstance(base, abstract.Class):
+      for m in methods:
+        if m in base.members:
+          if any(x.final for x in base.members[m].data):
+            ctx.errorlog.overriding_final_method(ctx.vm.frames, cls, base, m)
+          ann = base.get_annotated_local(m)
+          if ann and ann.final:
+            ctx.errorlog.overriding_final_attribute(ctx.vm.frames, cls, base, m)
+
+
 def make_class(node, name_var, bases, class_dict_var, cls_var, new_class_var,
                is_decorated, class_type, ctx):
   """Create a class with the name, bases and methods given.
@@ -498,6 +521,7 @@ def make_class(node, name_var, bases, class_dict_var, cls_var, new_class_var,
       elif class_type is not abstract.InterpreterClass:
         assert issubclass(class_type, abstract.InterpreterClass)
       val = class_type(name, bases, class_dict.pyval, cls, ctx)
+      _check_final_members(val, class_dict.pyval, ctx)
       val.is_decorated = is_decorated
     except mro.MROError as e:
       ctx.errorlog.mro_error(ctx.vm.frames, name, e.mro_seqs)
@@ -551,7 +575,7 @@ def _check_defaults(node, method, ctx):
 
 
 def make_function(name, node, code, globs, defaults, kw_defaults, closure,
-                  annotations, ctx):
+                  annotations, opcode, ctx):
   """Create a function or closure given the arguments."""
   if closure:
     closure = tuple(
@@ -563,6 +587,7 @@ def make_function(name, node, code, globs, defaults, kw_defaults, closure,
     name = "<lambda>"
   val = abstract.InterpreterFunction.make(
       name,
+      def_opcode=opcode,
       code=abstract_utils.get_atomic_python_constant(code),
       f_locals=ctx.vm.frame.f_locals,
       f_globals=globs,
